@@ -3,7 +3,7 @@
 from django.views.generic import TemplateView
 
 class IndexView(TemplateView):
-    template_name = "menu/index.html"
+    template_name = "index.html"
 
 class TestMenuView(TemplateView):
-    template_name = 'menu/test-menu.html'
\ No newline at end of file
+    template_name = 'test-menu.html'
\ No newline at end of file
